# reelname

[![PyPI version](https://img.shields.io/pypi/v/reelname.svg)](https://pypi.org/project/reelname/)
[![Python versions](https://img.shields.io/pypi/pyversions/reelname.svg?logo=python&logoColor=white)](https://pypi.org/project/reelname/)
[![CI](https://github.com/viseshrp/reelname/actions/workflows/main.yml/badge.svg)](https://github.com/viseshrp/reelname/actions/workflows/main.yml)

[![License: MIT](https://img.shields.io/github/license/viseshrp/reelname)](https://github.com/viseshrp/reelname/blob/main/LICENSE)
[![Code Style: Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://black.readthedocs.io/en/stable/)
[![Lint: Ruff](https://img.shields.io/badge/lint-ruff-000000.svg)](https://docs.astral.sh/ruff/)
[![Typing: mypy](https://img.shields.io/badge/typing-checked-blue.svg)](https://mypy.readthedocs.io/en/stable/)

> A tool to fix media file names

![Demo](https://raw.githubusercontent.com/viseshrp/reelname/main/demo.gif)

## 📐 Requirements

* Python >= 3.9

## 📦 Installation

```bash
pip install reelname
```

## 🧪 Usage

* To view the help message, run the following command:

```bash
reelname --help
```

## 🛠️ Features

* Fixes media filenames with random characters.

## 🧾 Changelog

See [CHANGELOG.md](https://github.com/viseshrp/reelname/blob/main/CHANGELOG.md)

## 🙏 Credits

* [Click](https://click.palletsprojects.com), for enabling delightful CLI development.
* Inspired by [Simon Willison](https://github.com/simonw)'s work.

## 📄 License

MIT © [Visesh Prasad](https://github.com/viseshrp)
